# avoca 

Quality assessement of data.

## Documentation 

Currenlty only the source code is documented.
We plan on generating a full documentation.


## License

This project is licensed under the MIT License.

It is managed by the a group of researchers at [Empa](https://www.empa.ch/web/s503/climate-gases)